/**
* feedpeep v1.0 - An application for studying color data through time from RSS feeds.
* 
* @author Eva Casado de Amezua . e_luanco@uoc.edu . www.ellaing.com
* @version 1.0
* 
* This application is offered as is and licensed under a Creative Commons Attribution-NonCommercial-NoDerivs 3.0 Unported License.
* Functions averageColour(), isCold(), different(), similar(), uniqueColours(), indexColours() and reduceColours() by Justin Windle (http://blog.soulwire.co.uk/).
* RGBtoHSV function from Kirupa user m90 (http://www.kirupa.com/forum/showthread.php?t=322958). 
*/

package {
	
	import com.core.graph;
	import flash.display.MovieClip;
	import flash.events.*;  
	import flash.text.TextField;
    import flash.text.TextFieldType;
	import com.utils.*;
	
	public class Main extends MovieClip{
		
		private var g:graph;
		
		public function Main() {
			g = new graph(this);
			addChild(g);
			prepareLoadButton();
			prepareButtons();
			g.x += 50 + 25;
			g.y = -5;
		}
		
		public function initLoad(e:MouseEvent):void{
			e.currentTarget.gotoAndStop(e.type)
			if (e.type == "click") {
				g.loadXML(inputUrl.text);
				inputUrl.type = TextFieldType.DYNAMIC;
				inputUrl.selectable = false;
				RemoveListeners();
			}
			e.currentTarget.visible = false;
			inputUrl.x -= 80;
			inputUrl.width += 80;
		}

		function RemoveListeners():void {
			loadUrl.removeEventListener(MouseEvent.CLICK, initLoad);
			}
		
		private function prepareLoadButton():void {
			loadUrl.test_text.text = "LOAD";
			loadUrl.buttonMode = true;
			loadUrl.useHandCursor = true;
			loadUrl.addEventListener(MouseEvent.CLICK, initLoad);
		}
		
		public function prepareButtons():void {
			b_d_hue.buttonMode = true;
			b_d_hue.useHandCursor = true;
			b_d_hue.test_text.text="hue";
			b_d_hue.addEventListener(MouseEvent.CLICK, onClickYAxis);
			b_d_hue.visible = false;
			
			b_d_value.buttonMode = true;
			b_d_value.useHandCursor = true;
			b_d_value.test_text.text="value";
			b_d_value.addEventListener(MouseEvent.CLICK, onClickYAxis);
			b_d_value.visible = false;
			
			b_d_saturation.buttonMode = true;
			b_d_saturation.useHandCursor = true;
			b_d_saturation.test_text.text="saturation";
			b_d_saturation.addEventListener(MouseEvent.CLICK, onClickYAxis);
			b_d_saturation.visible = false;
			
			b_d_points.buttonMode = true;
			b_d_points.useHandCursor = true;
			b_d_points.test_text.text = "hide points";
			b_d_points.visible = false;
			
			b_d_images.buttonMode = true;
			b_d_images.useHandCursor = true;
			b_d_images.test_text.text = "show imgs";
			b_d_images.visible = false;
			
			b_d_all.buttonMode = true;
			b_d_all.useHandCursor = true;
			b_d_all.test_text.text = "analyze";
			b_d_all.addEventListener(MouseEvent.CLICK, onClickAll);
			b_d_all.visible = false;
			
			creditsMc.buttonMode = true;
			creditsMc.useHandCursor = true;
			creditsMc.addEventListener(MouseEvent.CLICK, switchMcVisibility);
			
			helpMc.buttonMode = true;
			helpMc.useHandCursor = true;
			helpMc.addEventListener(MouseEvent.CLICK, switchMcVisibility);
		}
		
		private function switchMcVisibility(e:MouseEvent):void {
			if (e.currentTarget.currentFrame == 1) {
				e.currentTarget.gotoAndStop(5); 
				}else {
					e.currentTarget.gotoAndStop(1); 
					}
			e.currentTarget.parent.setChildIndex(e.currentTarget,e.currentTarget.parent.numChildren-1);
			}
		
		public function openDisplayButtons():void {
			b_d_hue.visible = true;
			b_d_value.visible = true;
			b_d_saturation.visible = true;
			b_d_all.visible = true;
			//inputUrl.text = g.get_imageSetName();
		}
		
		function onClickYAxis(e:MouseEvent){
			e.currentTarget.buttonMode = false;
			e.currentTarget.useHandCursor = false;
			g.yAxisGlobal(e.currentTarget.test_text.text);
			e.currentTarget.gotoAndStop("selected");
			activateHideShowPoints();
			activateHideShowImages();
			var targetLabel:String = e.currentTarget.test_text.text;
			if (targetLabel == "hue") { 
				b_d_value.gotoAndStop("enabled");
				b_d_saturation.gotoAndStop("enabled");
				}
			if (targetLabel == "value") { 
				b_d_hue.gotoAndStop("enabled");
				b_d_saturation.gotoAndStop("enabled");
				}
			if (targetLabel == "saturation") { 
				b_d_hue.gotoAndStop("enabled");
				b_d_value.gotoAndStop("enabled");
				}
		}
		
		function activateHideShowPoints():void {
			b_d_points.addEventListener(MouseEvent.CLICK, onClickPoints);
			b_d_points.visible = true;
			}
			
		function activateHideShowImages():void {
			b_d_images.addEventListener(MouseEvent.CLICK, onClickImages);
			b_d_images.visible = true;
			}
	
		function onClickPoints(e:MouseEvent){
			g.switchItemsVisibility();
			trace("currentLabel="+e.currentTarget.currentLabel)
			if (e.currentTarget.currentLabel == "selected") {
				e.currentTarget.gotoAndStop("enabled");
				e.currentTarget.test_text.text = "hide points";
				
				b_d_images.addEventListener(MouseEvent.CLICK, onClickImages);
				} 
				else if (e.currentTarget.currentLabel == "enabled") {
					e.currentTarget.gotoAndStop("selected");
					e.currentTarget.test_text.text = "show points";
					
					b_d_images.removeEventListener(MouseEvent.CLICK, onClickImages);
				}
		}
		
		function onClickImages(e:MouseEvent){
			g.switchImagesVisibility();
			trace("currentLabel="+e.currentTarget.currentLabel)
			if (e.currentTarget.currentLabel == "selected") {
				e.currentTarget.gotoAndStop("enabled");
				e.currentTarget.test_text.text="show imgs";
				} else	if (e.currentTarget.currentLabel == "enabled") {
				e.currentTarget.gotoAndStop("selected");
				e.currentTarget.test_text.text="hide imgs";
				}
		}
		
		function onClickAll(e:MouseEvent){
			e.currentTarget.buttonMode = false;
			e.currentTarget.useHandCursor = false;
			e.currentTarget.gotoAndStop("selected");
			g.initAll()
			b_d_all.removeEventListener(MouseEvent.CLICK, onClickAll);
			e.currentTarget.gotoAndStop("disabled");
		}
			
	}
	
}
	