﻿/**
* feedpeep v1.0 - An application for studying color data through time from RSS feeds.
* 
* @author Eva Casado de Amezua . e_luanco@uoc.edu . www.ellaing.com
* @version 1.0
* 
* This application is offered as is and licensed under a Creative Commons Attribution-NonCommercial-NoDerivs 3.0 Unported License.
* Functions averageColour(), isCold(), different(), similar(), uniqueColours(), indexColours() and reduceColours() by Justin Windle (http://blog.soulwire.co.uk/ ).
*/

package com.core {

	import flash.net.URLLoader;
	import flash.net.URLRequest;
	import flash.events.*;  
	import flash.display.*;
	import flash.text.*;
	import flash.geom.*;
	import fl.motion.Color;
	import com.utils.*;

	public class graph extends Sprite {
		
		private var xmlData:XML;
		private var xmlUrl:String;
		private var imageSetName:String;
		private var items:Array = new Array();
		private var maxItems:int = 81;
		private var avColors:Array = new Array();    
		private var loadingMC:MovieClip = new MovieClip();
		private var itemsDisplay:cSystem = new cSystem();
		private var connectorsDisplay:MovieClip = new MovieClip();
		private var tempDisplay:tDisplay = new tDisplay();
		private var barcodeDisplay:bDisplay = new bDisplay();
		private var emotionsDisplay:eDisplay = new eDisplay();
		private var meaningsDisplay:mDisplay = new mDisplay();
		private var analysisDisplay:bgAnalysis = new bgAnalysis();
		private var timeDisplay:MovieClip = new MovieClip();
		private var flag_connectorsHue:Boolean = false;
		private var flag_connectorsSat:Boolean = false;
		private var flag_connectorsValue:Boolean = false;
		private var flag_itemsVisibility:Boolean = false;
		private var flag_imagesVisibility:Boolean = false;
		private var firstDate:int;
		private var lastDate:int;
		private var dateRange:int;
		private var xOffset:int = 50;
		private var yOffset:int = 115;
		private var sWidth:int = 0;
		private var buttonSpace:int = 0;
		private var preloaderCounter:int = 0;
		private var main:Main;
		
		public function graph(p_main:Main) {
			main = p_main;
			itemsDisplay.visible = false;
			super();
		}
		
		public function loadXML(p_url:String):void {
			stringUtils.writeTrace(0, "loadXML");
			var loader = new URLLoader();
			xmlUrl = p_url;
			loader.addEventListener(Event.COMPLETE, extractData);
			loader.addEventListener(IOErrorEvent.IO_ERROR, riseLoadError);
			var request:URLRequest = new URLRequest(p_url);
			loader.load(request);
			}

		public function riseLoadError(event:IOErrorEvent):void {
			main.inputUrl.text = "ERROR LOADING! Please use a valid URL.";
			main.inputUrl.x += 80;
			main.inputUrl.width -= 80;
			main.inputUrl.type = TextFieldType.INPUT;
			main.inputUrl.selectable = true;
			main.loadUrl.visible = true;
			main.loadUrl.addEventListener(MouseEvent.CLICK, main.initLoad);
			}	

		private static function getImgFromMedia(pXml:XML,pItem:XML):String{
			var media:Namespace = pXml.namespace("media");
			var t_iUrl:String = "";
			if (pItem.media::content.@medium != undefined) {
			   t_iUrl = pItem.media::content.(@medium == "image").@url;
			}
			if (t_iUrl == "" && pItem.media::content.@type != undefined) {
			  t_iUrl = pItem.media::content.(@type == "image/jpeg").@url;
			}
			if (t_iUrl == "" && pItem.media::thumbnail != undefined) {
			  t_iUrl = pItem.media::thumbnail.@url;
			}
			return t_iUrl;
			}		
			
		private static function getImgFromEnclosure(pItem:XML):String{
			var t_iUrl:String = "";
			if(pItem.enclosure.@type!=undefined && pItem.enclosure.(@type=="image/jpeg")){
			  t_iUrl = pItem.enclosure.@url;
			}
			return t_iUrl;
			}
			
		private static function getImgFromHTML(pDesc:String):String{
			var t_iUrl:String = "";
			if(pDesc.indexOf("img")!=-1 && pDesc.indexOf("src=")!=-1){
				if (pDesc.indexOf(".jpg") != -1) {
				var begin = pDesc.indexOf("src=");
								  var after = pDesc.substring(begin);
								  var end = begin + after.indexOf(".jpg");
								  t_iUrl = pDesc.slice(begin+5, end+4);
				  }
			}
			if (!t_iUrl) {
			   t_iUrl = "";
			}
			return t_iUrl;
			}
			
		private function extractData(e:Event):void {
			stringUtils.writeTrace(0, "extractData");
			e.target.removeEventListener(Event.COMPLETE, extractData);
			xmlData = XML(e.target.data);
			var xmlTitle:String = xmlData.channel.title;
			this.set_imageSetName(xmlTitle);
			var media:Namespace = new Namespace(xmlData.namespace("media"));

			for each (var item in xmlData.channel.item) {
				var _pubDate:Date = new Date(item.pubDate.substr(0, 16) );
				var _descr:String = item.description;
				var _imgUrl = "";
				if(item.namespace("media") != undefined){
					_imgUrl = getImgFromMedia(xmlData,item);
				}
				if (!_imgUrl || _imgUrl == "") {
					_imgUrl = getImgFromEnclosure(item);
				}
				if (!_imgUrl || _imgUrl == "") {
				  _imgUrl = getImgFromHTML(_descr); 
				}
				if (_imgUrl != null && _imgUrl.length >= 5) {
					var _image:graphItem = new graphItem(_imgUrl, _pubDate, this.itemsDisplay);
					items.push(_image);
				}
			}
			items.sortOn("processedDate", Array.NUMERIC | Array.DESCENDING);
			processDateRange();
			buttonSpace = (1200 / items.length) - 2;
			itemsDisplay.timeRange.text = firstDate.toString() + " - " + lastDate.toString(); 
			preloader();
			calculateMaxNumItems();
			}

		private function preloader():void {
			stringUtils.writeTrace(0, "preloader");
			main.inputUrl.text  = "Load started!";//stringUtils.prepareTextField("Load launched!", 160, 858, 18);
			}	
		
		private function calculateMaxNumItems():void {
			var tmpUrl:String = xmlUrl;
			var httpControl:String = tmpUrl.slice(0,4);
			if (httpControl == "http") {
				maxItems = 21;
			}
			if (items.length >= 1) {				
				items.splice(maxItems - 1);
				fillImagesArray();
				}else {
					riseLoadError(null);
					}
			}
			
		private function fillImagesArray():void {
			stringUtils.writeTrace(0, "fillImagesArray");
			items[0].set_id(0);
			items[0].loadImage();
			itemsDisplay.addChild(items[0].get_image_mc());
			items[0].addEventListener(imageLoadEvent.LOAD_COMPLETED, runLoad);
			items[0].addEventListener(IOErrorEvent.IO_ERROR, riseLoadError);
			}
			
		private function runLoad(e:imageLoadEvent):void {
			stringUtils.writeTrace(0, "runLoad");
			preloaderCounter++;
			var v:int = Math.abs(preloaderCounter*100)/(items.length-1);
			main.inputUrl.text  = v + "% loaded, please wait...";
			
			var c:int = 0;
			c = e.currentTarget.get_id() + 1;
			if (c <= items.length - 2) {
				items[c].set_id(c);
				items[c].loadImage();
				itemsDisplay.addChild(items[c].get_image_mc());
				items[c].addEventListener(imageLoadEvent.LOAD_COMPLETED, runLoad);
				}
			if (c == items.length - 1) {
				items[c].set_id(c);
				items[c].loadImage();
				itemsDisplay.addChild(items[c].get_image_mc());
				items[c].addEventListener(imageLoadEvent.LOAD_COMPLETED, activateItemsDisplay);
				}
			}
			
		private function activateItemsDisplay(e:imageLoadEvent):void {
			stringUtils.writeTrace(0, "activateItemsDisplay");
			main.inputUrl.text = "Ready! Use buttons at the right to visualize data.";
			var n:int = items.length - 1;
			addChild(itemsDisplay);
			itemsDisplay.x += 20;
			itemsDisplay.y += 40;
			main.openDisplayButtons();
			} 	
			
		private function processDateRange():void {
			items.sortOn("processedDate", Array.NUMERIC);
			for (var i:int=0;i<items.length;i++){
				if (i == 0) { firstDate = items[0].get_pDate(); }
				if (i == items.length - 1) { lastDate = items[i].get_pDate(); }
				}
			dateRange = Math.abs(firstDate - lastDate);
			}
				
/* DISPLAY FUNCTIONS ---------------------------------------------------------------------------------------------*/			

		public function initAll():void {
			displayEmotions();
			displayTemperature();
			displayBarcode();
			displayMeanings();
			displayImageSetName();
			addChild(analysisDisplay);
			this.swapChildren(analysisDisplay, itemsDisplay);
			analysisDisplay.x = 35;
			analysisDisplay.y = 480;
			this.loadingMC.visible = false;
			}
						
		public function yAxisGlobal(p_v:String):void {
			stringUtils.writeTrace(0, "yAxisGlobal");
			stringUtils.writeTrace(1, "flag_itemsVisibility", flag_itemsVisibility)
			
			displayImageSetName();
			if (flag_itemsVisibility == false) {
				itemsDisplay.visible = true;
				switchItemsVisibility();
				this.loadingMC.visible = false;
				}
				
			var cSystemHeight:int = 330;
			var yValue:int = 0;
			var yValue_Past:int = 0;
			var lastImageCoords:Point = new Point();
			
			items[0].get_image_mc().x = 0 + xOffset;
			
			if (p_v == "hue") { 
				items[0].get_image_mc().y = ((-1)*items[0].get_hue())+cSystemHeight;
				}
			if (p_v == "saturation") { 
				items[0].get_image_mc().y = (( -1) * items[0].get_saturation() * 300) + cSystemHeight;
				}
			if (p_v == "value") { 
				items[0].get_image_mc().y = ((-1)*items[0].get_value())+cSystemHeight;
				}
			
			for (var i:int = 1; i < items.length; i++) {
				if (p_v == "hue") { 
					yValue = ((-1)*items[i].get_hue())+cSystemHeight;
					yValue_Past = ((-1)*items[i-1].get_hue())+cSystemHeight;
					}
				if (p_v == "saturation") { 
					yValue = (( -1) * items[i].get_saturation() * 300) + cSystemHeight;
					yValue_Past = (( -1) * items[i - 1].get_saturation() * 300) + cSystemHeight;
					}
				if (p_v == "value") { 
					yValue = ((-1)*items[i].get_value())+cSystemHeight;
					yValue_Past = ((-1)*items[i-1].get_value())+cSystemHeight;
					}
					
				var iMc:MovieClip=new MovieClip();
				iMc=items[i].get_image_mc();
				var iMc_previous:MovieClip=new MovieClip();
				iMc_previous=items[i-1].get_image_mc();
				var t_date1:int = items[i].get_pDate();
				var t_date2:int = items[i - 1].get_pDate();
				
				if (t_date1 == t_date2) {
					items[i].get_image_mc().x = items[i - 1].get_image_mc().x; // ((i - 1) * buttonSpace) + xOffset;
					var yOffset:int = yValue - yValue_Past;
					if (yOffset <= 30 && yOffset >=1) { 
						yOffset = 30; 
						}
					if (yOffset >= 30) { ;
						yOffset = 10;// yValue - yValue_Past; //Math.abs(yValue - yValue_Past); 
						}
					if (yOffset <= 0) { yOffset = 10;}
					items[i].get_image_mc().y = yValue + yOffset;
					lastImageCoords.x = iMc.x;
					lastImageCoords.y = iMc.y;
					}else{
						items[i].get_image_mc().x = (i * buttonSpace)+xOffset;
						items[i].get_image_mc().y = yValue;
						lastImageCoords.x = iMc.x;
						lastImageCoords.y = iMc.y;
						}
				drawTimeLine(items[i], lastImageCoords.x , lastImageCoords.y);
				items[i].rearrangeLoader();
				}
				
			drawTimeLine(items[0], items[0].get_image_mc().x , items[0].get_image_mc().y );
			items[0].rearrangeLoader();
			
			if (p_v == "hue" && flag_connectorsHue==false) { 
				drawAllConnectors(connectorsDisplay);
				flag_connectorsHue = true;
				}
			if (p_v == "saturation" && flag_connectorsSat==false) { 
				drawAllConnectors(connectorsDisplay);
				flag_connectorsSat = true;
				}
			if (p_v == "value" && flag_connectorsValue==false) { 
				drawAllConnectors(connectorsDisplay);
				flag_connectorsValue = true;
				}
				
			var ti:TextField = stringUtils.prepareTextField(p_v, items[0].get_image_mc().x-50, items[0].get_image_mc().y-10,10);
			var te:TextField = stringUtils.prepareTextField(p_v,lastImageCoords.x-30,lastImageCoords.y,10);
			connectorsDisplay.addChild(ti);
			connectorsDisplay.addChild(te);
			addChild(connectorsDisplay);
			this.swapChildren(itemsDisplay,connectorsDisplay);
		}
			
		public function displayTemperature():void {
			stringUtils.writeTrace(0, "displayTemperature");
			var tdCold:MovieClip = displayColdColors();
			var tdWarm:MovieClip = displayWarmColors();
			tdCold.x = 80;
			tdWarm.x = tdCold.x;
			tdCold.y = 0;
			tdWarm.y = tdCold.y + 25;
			tempDisplay.addChild(tdCold);
			tempDisplay.addChild(tdWarm);
			tempDisplay.x = 15;// stage.width - 280;
			tempDisplay.y = 10;
			analysisDisplay.addChild(tempDisplay);
			}
			
		private function displayColdColors():MovieClip {
			var tempTableCold:MovieClip = new MovieClip();
			var nColumns:int = 100;
			
			for (var i:int = 0; i < items.length; i++) {
				if(items[i].get_temperature()==true){
					var avColor:uint=items[i].get_averageColor();
					var bc_unit:MovieClip=new MovieClip();
					bc_unit.graphics.beginFill(0xFFFFFF);
					var bc_color:ColorTransform = bc_unit.transform.colorTransform;
					bc_color.color = items[i].get_featuredColor();//avColor;
					
					bc_unit.graphics.drawRect(0, 0, 10, 10);
					bc_unit.graphics.endFill();
					bc_unit.transform.colorTransform = bc_color;
					tempTableCold.addChild(bc_unit);
					bc_unit.x = (i * 10) ;//(i % nColumns) * (bc_unit.width + 1);
					bc_unit.y = Math.floor(i / nColumns) * (bc_unit.height + 10);
					bc_unit.name = String(i);
					
					bc_unit.buttonMode = true;
					bc_unit.useHandCursor = true;
					bc_unit.addEventListener(MouseEvent.CLICK , tempColorSwitchImageVisibility);
					bc_unit.addEventListener(MouseEvent.ROLL_OVER , tempColorSwitchDataVisibility);
					bc_unit.addEventListener(MouseEvent.ROLL_OUT , tempColorSwitchDataVisibility);
					}
				}
			return tempTableCold;
			}

		private function displayWarmColors():MovieClip {
			var tempTableWarm:MovieClip = new MovieClip();
			var nColumns:int = 100;
			
			for (var i:int = 0; i < items.length; i++) {
				if(items[i].get_temperature()==false){
					var bc_unit:MovieClip=new MovieClip();
					bc_unit.graphics.beginFill(0xFFFFFF);
					var bc_color:ColorTransform = bc_unit.transform.colorTransform;
					bc_color.color = items[i].get_featuredColor();//avColor;
					
					bc_unit.graphics.drawRect(0, 0, 10, 10);
					bc_unit.graphics.endFill();
					bc_unit.transform.colorTransform = bc_color;
					tempTableWarm.addChild(bc_unit);
					bc_unit.x = (i * 10) ;///(i % nColumns) * (bc_unit.width + 1);
					bc_unit.y = Math.floor(i / nColumns) * (bc_unit.height + 10);
					bc_unit.name = String(i);
					
					bc_unit.buttonMode = true;
					bc_unit.useHandCursor = true;
					bc_unit.addEventListener(MouseEvent.CLICK , tempColorSwitchImageVisibility);
					bc_unit.addEventListener(MouseEvent.ROLL_OVER , tempColorSwitchDataVisibility);
					bc_unit.addEventListener(MouseEvent.ROLL_OUT , tempColorSwitchDataVisibility);
					}
				}
			return tempTableWarm;
			}
			
		public function displayImageSetName():void {
			main.inputUrl.text = get_imageSetName() + " [" + items.length + " imgs]" + " [ " + items[0].get_pDate() + "-" + items[items.length - 1].get_pDate() + "]";
			}
			
		public function displayBarcode():void {
			stringUtils.writeTrace(0, "displayBarcode");
			var bc_width:int = 486;
			var c:int = 0;
			var barcode:MovieClip = new MovieClip();
			
			for(var i:int=0;i<items.length;i++){
				var d:Number = 0;
				var bc_unit_width:int=bc_width/items.length;
				if(i>0){
					var bc_color_now:uint = items[i].get_averageColor();
					var bc_color_pre:uint = items[i - 1].get_averageColor();
					d=imageTools.isSimilar(bc_color_now,bc_color_pre);
				}
				if (d > 1500000) {
					c++;
					var avColor:uint = items[i].get_averageColor();
					var bc_unit:MovieClip=new MovieClip();
					bc_unit.graphics.beginFill(0xFFFFFF);
					var bc_color:ColorTransform = bc_unit.transform.colorTransform;
					bc_color.color = avColor;
					bc_unit.cname = avColor;
					bc_unit.graphics.drawRect(0, 0, bc_unit_width, 10);
					bc_unit.graphics.endFill();
					bc_unit.transform.colorTransform = bc_color;
					//barcodeDisplay.addChild(bc_unit);
					barcode.addChild(bc_unit);
					bc_unit.x = (c * bc_unit_width);
					bc_unit.y = 3;
					bc_unit.buttonMode = true;
					bc_unit.useHandCursor = true;
					bc_unit.addEventListener(MouseEvent.CLICK , displayColorCode);
					}
				}
			barcodeDisplay.addChild(barcode);
			barcodeDisplay.x = tempDisplay.x;// 50;// stage.width - 450;
			barcodeDisplay.y = tempDisplay.y + tempDisplay.height + 10;// 528;//40;
			analysisDisplay.addChild(barcodeDisplay);
			barcode.width = bc_width;
			barcode.x += 50;
			}
			
		public function displayEmotions():void {
			stringUtils.writeTrace(0, "displayEmotions");
			var e_width:int = 520;
			var emotions:Array = new Array();
			var t:TextField = new TextField();
			var s:String = "\n";
			var tt:String = "";
			var maxEmoValue:int = 0;
			var e_unit_previous:MovieClip = new MovieClip();
			var emotionsMc:MovieClip = new MovieClip();
			
			for(var i:int=0;i<items.length;i++){
				var n:int = items[i].get_prevailingColor();
				var c:int = emotions[n];
				c = c+ 1;
				emotions[n] = c;
				if (maxEmoValue <= c) { 
					maxEmoValue = c; 
					}
				}
			for (var j:int = 0; j < emotions.length; j++ ) {	
				var e_unit_width:int = 10;// e_width / emotions.length;
				var e_unit:MovieClip=new MovieClip();
				e_unit.graphics.beginFill(0xFFFFFF);
				var e_color:ColorTransform = e_unit.transform.colorTransform;
				var cFC:uint = imageTools.colorFamilyCode(j);
				e_color.color = cFC;
				var e_unit_height:int = (e_width * emotions[j]) / maxEmoValue;	
				
				if (e_unit_height >= 1) {
					e_unit.graphics.drawRect(0, 20, e_unit_height, e_unit_width); 
					e_unit.graphics.endFill();
					e_unit.transform.colorTransform = e_color;
					tt += imageTools.colorFamilyNameDesc(j,true,true)+s;
					emotionsMc.addChild(e_unit);
					e_unit.x = (e_unit_previous.x + e_unit_previous. width) + 5;
					e_unit.name = String(j);
					e_unit.buttonMode = true;
					e_unit.useHandCursor = true;
					e_unit.addEventListener(MouseEvent.CLICK , displayFamilyName);
					e_unit.addEventListener(MouseEvent.ROLL_OVER , colorFamilySwitchDataVisibility);
					e_unit.addEventListener(MouseEvent.ROLL_OUT , colorFamilySwitchDataVisibility);
					e_unit_previous = e_unit;
					}
			}
			emotionsDisplay.addChild(emotionsMc);
			emotionsMc.width = e_width;
			emotionsMc.x = 80;
			emotionsMc.y = -18;
			emotionsDisplay.x = barcodeDisplay.x + 10;// 50;// stage.width - 430;
			emotionsDisplay.y = barcodeDisplay.y + barcodeDisplay.height + 65;//555;// 180;
			analysisDisplay.addChild(emotionsDisplay);
			}
			
		public function displayMeanings():void {
			stringUtils.writeTrace(0, "displayMeanings");
			var e_width:int = 100;
			var emotions:Array = new Array();
			var familiesCounter:int = 0;
			var s:String = "\n";
			var e_unit_previous:MovieClip = new MovieClip();
			
			for(var i:int=0;i<items.length;i++){
				var n:int = items[i].get_prevailingColor();
				var c:int = emotions[n];
				c = c+ 1;
				emotions[n] = c;
				}
			for (var j:int = 0; j < emotions.length; j++ ) {
				var e_unit_width:int=e_width/emotions.length;
				var e_unit:MovieClip=new MovieClip();
				e_unit.graphics.beginFill(0xFFFFFF);
				var e_color:ColorTransform = e_unit.transform.colorTransform;
				var cFC:uint = imageTools.colorFamilyCode(j);
				e_color.color = cFC;
				var h:int = 20 * emotions[j];
				if (h > 0) {
					familiesCounter += 1;
					var mWeight:int = 10;
					mWeight = emotions[j] * 3;
					if (mWeight <= 9) { mWeight = 9; }
					if (mWeight >= 22) { mWeight = 22; }
					var t:TextField = stringUtils.prepareTextField(imageTools.colorFamilyNameDesc(j,false,true), -60,0, mWeight);
					e_unit.transform.colorTransform = e_color;
					e_unit.graphics.endFill();
					e_unit.addChild(t);
					meaningsDisplay.addChild(e_unit);
					e_unit.y = e_unit_previous.y + e_unit_previous.height ;// (familiesCounter * 10) + e_unit.height;//(familiesCounter * e_unit_width) + 10;
					e_unit_previous = e_unit;
					}
				}
			var dX:int = 0;
			if (tempDisplay.width > barcodeDisplay.width) {
				dX = tempDisplay.width
				}else {
					dX = barcodeDisplay.width
					}
			meaningsDisplay.t_width.visible = false;
			meaningsDisplay.x = dX + 60;// 680 + 200;
			meaningsDisplay.y -= 15;// 450;
			meaningsDisplay.width = Math.abs((1000 - dX)*2)+210;// 750;
			if(meaningsDisplay.height >= 120){
				meaningsDisplay.height = 120;
			}
			if (meaningsDisplay.width >= 1000) {
				meaningsDisplay.width = 1000;
				}
			analysisDisplay.addChild(meaningsDisplay);
			}		

/* LISTENERS, DISPLAY OPTIONS, ETC.  ---------------------------------------------------------------------------------------------*/
			
		public function displayColorCode(e:MouseEvent):void {
			barcodeDisplay.t_barcode.text = "#" + e.target.cname.toString(16).toUpperCase();
			}
		
		public function displayFamilyName(e:MouseEvent):void {
			emotionsDisplay.t_family.text = imageTools.colorFamilyNameDesc(e.target.name, true, true);
			}
		
		private function tempColorSwitchImageVisibility(e:MouseEvent):void {
			var n:int = int(e.currentTarget.name);
			items[n].viewImage(e);
			}
			
		private function tempColorSwitchDataVisibility(e:MouseEvent):void {
			var n:int = int(e.currentTarget.name);
			items[n].switchDataVisibility();
			}
			
		private function colorFamilySwitchDataVisibility(e:MouseEvent):void {
			var n:int = int(e.currentTarget.name);
			for (var i:int = 0; i < items.length; i++ ) {
				if (items[i].get_prevailingColor() == n) {
					items[i].switchDataVisibility();
					}
				}
			}
		
		public function drawTimeLine(p_I:graphItem, p_Ix:int, p_Iy:int):void {
			var iDisplay_h:int = 440;// itemsDisplay.height;
			var timeline_mc:MovieClip = new MovieClip();
			timeline_mc.graphics.lineStyle(1, 0x666666);
			timeline_mc.graphics.moveTo(p_Ix+30,iDisplay_h-35);
			timeline_mc.graphics.lineTo(p_Ix + 30, 400);//35);// Math.abs(p_Iy + 65));
			var t:TextField = stringUtils.prepareTextField(p_I.get_pDate().toString(), p_Ix-60,iDisplay_h-60, 10);
			timeline_mc.addChild(t);
			timeDisplay.addChild(timeline_mc);
			addChild(timeDisplay);
			}		
	
		public function switchItemsVisibility():void {
			if (flag_itemsVisibility == false) {
				flag_itemsVisibility = true;
				}else { 
					flag_itemsVisibility = false; 
					}
			for (var i:int = 0; i < items.length; i++ ) {
				var iMc:MovieClip=new MovieClip();
				iMc=items[i].get_image_mc();
				iMc.visible = flag_itemsVisibility; 
				}
			}
			

		public function switchImagesVisibility():void {
			if (flag_imagesVisibility == false) {
				flag_imagesVisibility = true;
				}else { 
					flag_imagesVisibility = false; 
					}
			for (var i:int = 0; i < items.length ; i++ ) {
				if (flag_imagesVisibility == true ) {
					items[i].forceViewImage();
					}
				if (flag_imagesVisibility == false ) {
						items[i].forceHideImage();
						}
				}
			}
	 
/* CONNECTOR FUNCTIONS ---------------------------------------------------------------------------------------------*/

		public function drawConnector(b:int,a:int):void{
			var iMc:MovieClip=new MovieClip();
			iMc=items[b].get_image_mc();
			var iMc_previous:MovieClip=new MovieClip();
			iMc_previous = items[a].get_image_mc();
			
			var shape:Sprite = new Sprite();
			shape.x = 0;
			shape.y =0;
			shape.graphics.lineStyle(1,0x999999);
			shape.graphics.moveTo(iMc.x+30,iMc.y+50);
			shape.graphics.lineTo(iMc_previous.x+30,iMc_previous.y+50);
			shape.graphics.endFill();
			addChild(shape);
			}
		  
		public function drawAllConnectors(m:MovieClip):void {
			stringUtils.writeTrace(0, "drawAllConnectors");
			var connectors:MovieClip=new MovieClip();
			for(var i:int=1;i<items.length;i++){
				drawConnector(i,i-1);
			}
			m.addChild(connectors);
			}
			
		public function set_imageSetName(p_name:String):void {
			imageSetName = p_name;
			}
			
		public function get_imageSetName():String {
			return imageSetName;
			}
			
	}

}