/**
* feedpeep v1.0 - An application for studying color data through time from RSS feeds.
* 
* @author Eva Casado de Amezua . e_luanco@uoc.edu . www.ellaing.com
* @version 1.0
* 
* This application is offered as is and licensed under a Creative Commons Attribution-NonCommercial-NoDerivs 3.0 Unported License.
* Functions averageColour(), isCold(), different(), similar(), uniqueColours(), indexColours() and reduceColours() by Justin Windle (http://blog.soulwire.co.uk/ ).
*/

package  com.utils {

	import flash.display.*;
	import flash.geom.*;
	
	public class imageTools {

		 public static function averageColour( b:BitmapData ):uint {
			 
			reduceColours( b, 16 );
			var R:Number = 0;
			var G:Number = 0;
			var B:Number = 0;
			var n:Number = 0;
			var p:Number;
			for (var x:int = 0; x < b.width; x++) {
				for (var y:int = 0; y < b.height; y++) {
					p = b.getPixel(x, y);
					R += p >> 16 & 0xFF;
					G += p >> 8  & 0xFF;
					B += p       & 0xFF;
					n++
				}
			}
			R /= n;
			G /= n;
			B /= n;
			return R << 16 | G << 8 | B;
			}
		
		public static function isCold( p_b:BitmapData ):Boolean {
			reduceColours( p_b, 16 );
			var R:Number = 0;
			var G:Number = 0;
			var B:Number = 0;
			var n:Number = 0;
			var p:Number;
			for (var x:int = 0; x < p_b.width; x++) {
				for (var y:int = 0; y < p_b.height; y++) {
					p = p_b.getPixel(x, y);
					R += p >> 16 & 0xFF;
					G += p >> 8  & 0xFF;
					B += p       & 0xFF;
					n++
				}
			}
			R /= n;
			G /= n;
			B /= n;
			return B>R;
			}
		
		public static function isSimilar( c1:uint, c2:uint):Number{
				var difference:Number = Math.abs(c1 - c2);
				return difference;
			}
		
		public static function reduceColours( b:BitmapData, colours:int = 16 ):void {
			var Ra:Array = new Array(256);
			var Ga:Array = new Array(256);
			var Ba:Array = new Array(256);
			var n:Number = 256 / ( colours / 3 );
			for (var i:int = 0; i < 256; i++){
				Ba[i] = Math.floor(i / n) * n;
				Ga[i] = Ba[i] << 8;
				Ra[i] = Ga[i] << 8;
			}
			b.paletteMap( b, b.rect, new Point(), Ra, Ga, Ba );
		}
			
		public static function getFeaturedColor(uniqueColours:Array, p_c:int):uint {
			var prevailingColorF:int = p_c;
			var featuredColourFamily:int;
			var fc:uint;
			for (var i:int = 0; i < uniqueColours.length; i++ ) {
				featuredColourFamily = prevailingColorFamily(uniqueColours[i].colour);
				///trace("i="+i+" length:"+uniqueColours.length+" +++prevailingColorF="+prevailingColorF+"+++getFeaturedColor+++"+uniqueColours[i].colour+"+++featuredColourFamily+++"+featuredColourFamily);
				if ( featuredColourFamily != p_c && featuredColourFamily != 2  && featuredColourFamily != 0) {
					fc = uniqueColours[i].colour;
					i = uniqueColours.length;
					}
				}
			return fc;
			}
		
		public static function prevailingColorFamily(c:int){//, p_r:int, p_g:int, p_b:int):int {
			var iColor:int = -1;
			var r:int = extractRed(c);
			var g:int = extractGreen(c);
			var b:int = extractBlue(c);
			var r_g:int = Math.abs(r - g);
			var g_b:int = Math.abs(g - b);
			var r_b:int = Math.abs(r - b);
			
			//Red range conditionals
			if (r >= 127) {
				if (b > 86 && 212 >= b > 44 && r >= b && b > g && r_b <= 86) {
					iColor = 7;
					//pColor = "Pink";
					}
				if (g >= 44 && b >= 44 && g >= b && r_g <= 170) {
					iColor = 10;
					//pColor = "Brown";
					}
				if (g <= 44 && b <= 44) {
					iColor = 3;
					//pColor = "Red";
					}
				if (r >= 212 && g >= 212 && b <= 44) {
					iColor = 8;
					//pColor = "Yellow";
					}
				if (r >= 170 && 212 >= g && g >= 86 && b <= 86) {
					iColor = 6;
					//pColor = "Orange";
					}
				if (r <= 212 && g >= 44 && b <= 170 && r <= g && g >= b) {
					iColor = 4;
					//pColor = "Green";
					}
				}
			//Grey range conditionals
			if (r >= 44 && r == g && r == b || r >= 44 && r_g <= 20 && g_b <= 20 && r_b <= 20) {
				iColor = 2;
				//pColor = "Grey";
				}
			//Black range conditionals
			if (r <= 44 && g <= 44 && b <= 44 ) {
				iColor = 0;
				//pColor = "Black";
				}
			//White range conditionals
			if (r >= 212 && g >= 212 && b >= 212 || r + g + b >= 636 ) {//r_g + r_b + g_b < 60) {
				iColor = 1;
				//pColor = "White";
				}
			//Blue range conditionals
			if (b >= 44) {
				if (r <= 44 && g <= 212 && g <= b) {
					iColor = 5;
					//pColor = "Blue";
					}
				if (r <= 212 && r >= 44 && g <= 127 && b >= g && r >= g && r_b <= 86) { //r <= b 
					iColor = 9;
					//pColor = "Purple";
					}
				}
			//Else 
			if (iColor == -1) {
				if (r > g && r > b) {
					iColor = 3;
					//pColor = "Red";
					}
				if (g > r && g > b) {
					iColor = 4;
					//pColor = "Green";
					}
				if (b > r && b > g) {
					iColor = 5;
					//pColor = "Blue";
					}
				}
			return iColor;
			}
		
		public static function colorFamilyNameDesc(n:int, colorname:Boolean, desc:Boolean):String {
			var cName:String = "";
			var cDesc:String = "";
			var s:String = "\n";
			switch(n) { 
				case 0: 
					cName = "black";
					cDesc = "death, elegance, evil, individuality, secrecy, rebellion";
					break; 
				case 1: 
					cName = "white"; 
					cDesc = "bravery, holiness, knowledge, peace, purity, virtue";
					break; 
				case 2: 
					cName = "grey"; 
					cDesc = "conservative, formality, moody, neutrality, speed";
					break; 
				case 3: 
					cName = "red"; 
					cDesc = "anger, danger, excitement, leadership, love, passion, power";
					break; 
				case 4: 
					cName = "green"; 
					cDesc = "abundance, nature, peace, reborn, youth";
					break; 
				case 5: 
					cName = "blue"; 
					cDesc = "calm, cold, magic, responsibility, sadness, trueness";
					break; 
				case 6: 
					cName = "orange";
					cDesc = "desire, energy, happiness, vitality";
					break; 
				case 7: 
					cName = "pink";
					cDesc = "beauty, friendship, glamour, romance, spring";
					break; 
				case 8: 
					cName = "yellow";
					cDesc = "curiosity, deceit, happiness, hope, intelligence, warmth";
					break; 
				case 9: 
					cName = "purple";
					cDesc = "creativity, nobility, poison, rage, wealth, wisdom";
					break; 
				case 10: 
					cName = "brown";
					cDesc = "dependability, nature, poverty, wholesomeness";
					break; 
				default: 
					cName = "grey"; 
					cDesc = "conservative, formality, moody, neutrality, speed";
					break; 
			}
			if (desc == false) { 
				s = "";
				cDesc = ""; 
				}
			if (colorname == false) {
				s = "";
				cName = "";
				}
			return cName + s + cDesc;
			}
			
		public static function colorFamilyCode(n:int):uint {
			/*	
			 0 black
			 1 white
			 2 grey
			 3 red
			 4 green
			 5 blue
			 6 orange
			 7 pink
			 8 yellow
			 9 purple
			 10 brown
			 */
			var c:uint = 0;
			switch(n) { 
				case 0: 
					c = 0x000000;
					break; 
				case 1: 
					c = 0xFFFFFF; 
					break; 
				case 2: 
					c = 0x666666; 
					break; 
				case 3: 
					c = 0xF03C2C; 
					break; 
				case 4: 
					c = 0x419A07; 
					break; 
				case 5: 
					c = 0x4169E2; 
					break; 
				case 6: 
					c = 0xF48A28;
					break; 
				case 7: 
					c = 0xF067B2;
					break; 
				case 8: 
					c = 0xFEF919;
					break; 
				case 9: 
					c = 0x9845ED;
					break; 
				case 10: 
					c = 0x865A3C;
					break; 
				default: 
					c = 0xC3C3C3; 
					break; 
			}
			return c;
			}
		
		public static function extractRed(c):Number {
			return Number((c >> 16) & 0xFF);
			}

		public static function extractGreen(c):Number {
			return Number((c >> 8) & 0xFF);
			}

		public static function extractBlue(c):Number {
			return Number(c & 0xFF);
			}
		
		public static function indexColours( source:BitmapData, sort:Boolean = true ):Array {
			reduceColours( source, 256 );
			var n:Object = {};
			var a:Array = [];
			var p:int;
			for (var x:int = 0; x < source.width; x++) {
				for (var y:int = 0; y < source.height; y++) {
					p = source.getPixel(x, y);
					n[p] ? n[p]++ : n[p] = 1;
				}
			}
			for (var c:String in n) {
				a.push ( { colour:c, count:n[c] } );
			}
			function byCount( a:Object, b:Object ):int {
				if ( a.count > b.count ) return 1;
				if ( a.count < b.count ) return -1;
				return 0;
			}
			return a.sort( byCount, Array.DESCENDING );
			}

		public static function uniqueColours( colours:Array, maximum:int, tolerance:Number = 0.01 ):Array {

			var unique:Array = new Array();
			unique.push(colours[0]);
			if (colours.length < maximum) {
				maximum = colours.length;
				}
			for (var i:int = 1; i <= maximum - 1; i++)
			{
				if ( different( colours[i].colour, unique, tolerance ) == true ){
							unique.push( colours[i] )
						}
				}
			return unique;
			}
		
		public static function similar( colour1:uint, colour2:uint, tolerance:Number = 0.01 ):Boolean {
			var RGB1:Object = Hex24ToRGB( colour1 );
			var RGB2:Object = Hex24ToRGB( colour2 );
			tolerance = tolerance * ( 255 * 255 * 3 ) << 0;
			var distance:Number = 0;
			
			distance += Math.pow( RGB1.red - RGB2.red, 2 );
			distance += Math.pow( RGB1.green - RGB2.green, 2 );
			distance += Math.pow( RGB1.blue - RGB2.blue, 2 );
			
			return distance <= tolerance;
			}
	
		public static function different( colour:uint, colours:Array, tolerance:Number = 0.01 ):Boolean {
			for (var i:int = 0; i < colours.length; i++) 
			{
				if ( similar( colour, colours[i], tolerance ) )
				{
					return false;
				}
			}
			return true;
			}
		
		public static function Hex24ToRGB( hex:uint ):Object {
				var R:Number = hex >> 16 & 0xFF;
				var G:Number = hex >> 8 & 0xFF;
				var B:Number = hex & 0xFF;
				return { red:R, green:G, blue:B };
			}
		
		public static function RGBtoHSV(R:Number,G:Number,B:Number):Object{
            var HSV:Object = {};
            
            var min:Number=R;
            if (G<min) {min=G;}
            if (B<min) {min=B;}

            var max:Number=R;
            if (G>max) {max=G;}
            if (B>max) {max=B;}

            HSV.V = max;
            var deltaColor:Number = max - min;			
            if (max!=0) {
                HSV.S=deltaColor/max;
                if (R==max) {
                    HSV.H = ( G - B ) / deltaColor; // between yellow & magenta
                } else if ( G == max ) {
                    HSV.H = 2 + ( B - R ) / deltaColor; // between yellow & magenta
                } else {
                    HSV.H = 4 + ( R - G ) / deltaColor; // between magenta & cyan
                }
                HSV.H*=60;
                if (HSV.H <= 0) {
                    HSV.H+=360;
                }
            } else {
                HSV.S = 0;
                HSV.H = 0;
                HSV.V = 0;
            }
            return HSV;
        }

	}
	
}
